@@ -164,7 +164,11 @@ namespace Banshee
         {
             SimpleDisc mb_disc = o as SimpleDisc;
             
-            mb_disc.QueryCDMetadata();
+            try {
+                mb_disc.QueryCDMetadata();
+            } catch(Exception) {
+                return;
+            }
             
             int min = tracks.Length < mb_disc.Tracks.Length 
                 ? tracks.Length : mb_disc.Tracks.Length;
@@ -233,7 +237,7 @@ namespace Banshee
             try {
                 using(UnixStream stream = UnixFile.Open(device_node, 
                     (Mono.Unix.OpenFlags)(UnixFileUtil.OpenFlags.O_RDONLY | 
-					UnixFileUtil.OpenFlags.O_NONBLOCK))) {
+                    UnixFileUtil.OpenFlags.O_NONBLOCK))) {
                     return ioctl(stream.Handle, open
                         ? EjectOperation.Open
                         : EjectOperation.Close) == 0;
@@ -317,10 +321,17 @@ namespace Banshee
         
         public AudioCdCore()
         {
-            IntPtr ptr = cd_detect_new();
-            if(ptr == IntPtr.Zero) {
-                throw new ApplicationException(
-                    Catalog.GetString("Could not initialize HAL for CD Detection"));
+            IntPtr error_ptr = IntPtr.Zero;
+            IntPtr ptr = cd_detect_new(out error_ptr);
+            if(ptr == IntPtr.Zero || error_ptr != IntPtr.Zero) {
+                string error_str = "Unknown HAL initialization error";
+                if(error_ptr != IntPtr.Zero) {
+                    error_str = GLib.Marshaller.Utf8PtrToString(error_ptr);
+                    GLib.Marshaller.Free(error_ptr);
+                }
+
+                throw new ApplicationException(Catalog.GetString("Could not initialize HAL for CD Detection") 
+                    + ": " + error_str);
             }
             
             handle = new HandleRef(this, ptr);
@@ -331,7 +342,7 @@ namespace Banshee
             cd_detect_set_device_added_callback(handle, AddedCallback);
             cd_detect_set_device_removed_callback(handle, RemovedCallback);    
             
-            DebugLog.Add("Audio CD Core Initialized");
+            Banshee.Logging.LogCore.Instance.PushDebug("Audio CD Core Initialized", "");
             
             BuildInitialList();
         }
@@ -341,6 +352,24 @@ namespace Banshee
             cd_detect_free(handle);
         }
     
+        private AudioCdDisk CreateDisk(DiskInfo halDisk)
+        {
+            try {
+                AudioCdDisk disk = new AudioCdDisk(halDisk);
+                disk.Updated += OnAudioCdDiskUpdated;
+                if(disk.Valid) {
+                    disks[disk.Udi] = disk;
+                }
+                return disk;
+            } catch(Exception e) {
+                Exception temp_e = e; // work around mcs #76642
+                Banshee.Logging.LogCore.Instance.PushError(Catalog.GetString("Could not Read Audio CD"), 
+                    temp_e.Message);
+            }
+            
+            return null;
+        }
+       
         private void OnDiskAdded(IntPtr udiPtr)
         {
             string udi = Marshal.PtrToStringAnsi(udiPtr);
@@ -360,11 +389,10 @@ namespace Banshee
                     continue;
                 }
                 
-                AudioCdDisk disk = new AudioCdDisk(halDisk);
-                disk.Updated += OnAudioCdDiskUpdated;
-
-                if(disk.Valid)
-                    disks[disk.Udi] = disk;
+                AudioCdDisk disk = CreateDisk(halDisk);
+                if(disk == null) {
+                    continue;
+                }
                 
                 HandleUpdated();
                 
@@ -434,12 +462,7 @@ namespace Banshee
                 return;
 
             foreach(DiskInfo halDisk in halDisks) {
-                AudioCdDisk disk = new AudioCdDisk(halDisk);
-                disk.Updated += OnAudioCdDiskUpdated;
-                
-                if(disk.Valid) {
-                    disks[disk.Udi] = disk;
-                }
+                CreateDisk(halDisk);
             }
 
             HandleUpdated();
@@ -466,7 +489,7 @@ namespace Banshee
         }
         
         [DllImport("libbanshee")]
-        private static extern IntPtr cd_detect_new();
+        private static extern IntPtr cd_detect_new(out IntPtr error_ptr);
         
         [DllImport("libbanshee")]
         private static extern void cd_detect_free(HandleRef handle);
