@@ -36,6 +36,7 @@ using Gnome;
 using GConf;
 using Mono.Unix;
 
+using Banshee.Logging;
 
 namespace Banshee
 {
@@ -65,8 +66,6 @@ namespace Banshee
         private Library library;
         private GConf.Client gconfClient;
         
-        private LogCore log;
-        
         public static Core Instance
         {
             get {
@@ -113,15 +112,14 @@ namespace Banshee
             
             set {
                 activePlayer = value;
-                DebugLog.Add("Active Player Engine is now '" + 
-                    activePlayer.EngineName + "'");
+                Core.Log.PushDebug("Changed active player engine", activePlayer.EngineName);
             }
         }
         
         public static LogCore Log
         {
             get {
-                return Instance.log;
+                return LogCore.Instance;
             }
         }
 
@@ -133,7 +131,6 @@ namespace Banshee
             Gstreamer.Initialize();
 
             dbusServer = new DBusServer();
-            log = new LogCore();
 
             if(!Directory.Exists(Paths.ApplicationData))
                 Directory.CreateDirectory(Paths.ApplicationData);
@@ -153,23 +150,28 @@ namespace Banshee
             }
 
             if(Player == null) {
-                    Console.Error.WriteLine("Could not load A PlayerEngine Core!");
-                    System.Environment.Exit(1);
+                Console.Error.WriteLine("Could not load A PlayerEngine Core!");
+                System.Environment.Exit(1);
             }
 
             Player.Initialize();
-            DebugLog.Add("Loaded PlayerEngine core: " + Player.EngineName);
+            Core.Log.PushDebug("Loaded PlayerEngine core", Player.EngineName);
 
             if(AudioCdPlayer == null) {
-                    Console.Error.WriteLine("Could not load AudioCdPlayer!");
-                    System.Environment.Exit(1);
+                Console.Error.WriteLine("Could not load AudioCdPlayer!");
+                System.Environment.Exit(1);
             }
 
             AudioCdPlayer.Initialize();
-            DebugLog.Add("Loaded AudioCdPlayerEngine core: " + 
-                 AudioCdPlayer.EngineName);
             
-            AudioCdCore = new AudioCdCore();
+            Core.Log.PushDebug("Loaded AudioCdPlayerEngine core", AudioCdPlayer.EngineName);
+            
+            try {
+                AudioCdCore = new AudioCdCore();
+            } catch(ApplicationException e) {
+                Core.Log.PushWarning("Audio CD support will be disabled for this instance", e.Message, false);
+            }
+            
             IpodCore = new IpodCore();
 
             StockIcons.Initialize();
@@ -214,7 +216,9 @@ namespace Banshee
         {
             library.TransactionManager.CancelAll();
             library.Db.Close();
-            AudioCdCore.Dispose();
+            if(AudioCdCore != null) {
+                AudioCdCore.Dispose();
+            }
             IpodCore.Dispose();
         }
         
